# Bahy Bot Maker

This is a warper for the [BlueSky Python SDK](https://atproto.blue/en/latest/)

⚠️ This package is still under development

⚠️ It is **HIGHLY** recommended to install this package in a **NEW** python virtual environment to avoid package conflicts

## TODO
- Write a README 😅

## Documentation

- `bahy_bot_maker` in terminal to make sure the installation was successful

- `activate_bot(username: str, password: str)` : Takes the credentials of your bot and returns the `Client` and `Profile`

<div align="center">
<h1>Bahy 2025</h1>
<p><em>All rights reserved</em></p>
</div>